Module: NuecaRailsInterfaces::V1::DataSource::NodeInterface
- Defined in:
- lib/nueca_rails_interfaces/v1/data_source/node_interface.rb
Overview
Data source node. They are used as actual sources of data for records, may it be in terms of presentation or multiple sources of basis for data. Include this module to create a data source node.
Instance Attribute Summary collapse
-
#record ⇒ Object
readonly
Returns the value of attribute record.
Class Method Summary collapse
-
.included(subclass) ⇒ Object
Automatically delegate missing methods to the record.
Instance Method Summary collapse
-
#initialize(record) ⇒ Object
The record itself!.
Instance Attribute Details
#record ⇒ Object (readonly)
Returns the value of attribute record.
17 18 19 |
# File 'lib/nueca_rails_interfaces/v1/data_source/node_interface.rb', line 17 def record @record end |
Class Method Details
.included(subclass) ⇒ Object
Automatically delegate missing methods to the record.
12 13 14 |
# File 'lib/nueca_rails_interfaces/v1/data_source/node_interface.rb', line 12 def included(subclass) subclass.delegate_missing_to(:record) end |
Instance Method Details
#initialize(record) ⇒ Object
The record itself!
20 21 22 |
# File 'lib/nueca_rails_interfaces/v1/data_source/node_interface.rb', line 20 def initialize(record) @record = record end |