Exception: NuecaRailsInterfaces::V1::DataSource::NotFound
- Inherits:
-
StandardError
- Object
- StandardError
- NuecaRailsInterfaces::V1::DataSource::NotFound
- Defined in:
- lib/nueca_rails_interfaces/v1/data_source/base_interface.rb
Overview
Error class for when the data source class is not found. Only use this for the context of data sources.